==> kubernetes-model-apiextensions-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceConversionFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class CustomResourceConversionFluentImpl<A extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent<A>{
  public CustomResourceConversionFluentImpl() {
  }
  public CustomResourceConversionFluentImpl(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversion instance) {
    this.withStrategy(instance.getStrategy()); 
    this.withWebhook(instance.getWebhook()); 
  }
  private java.lang.String strategy;
  private io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionBuilder webhook;
  public java.lang.String getStrategy() {
    return this.strategy;
  }
  public A withStrategy(java.lang.String strategy) {
    this.strategy=strategy; return (A) this;
  }
  public java.lang.Boolean hasStrategy() {
    return this.strategy != null;
  }
  
  /**
   * Method is deprecated. use withStrategy instead.
   */
  @java.lang.Deprecated
  public A withNewStrategy(java.lang.String arg0) {
    return (A)withStrategy(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildWebhook instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion getWebhook() {
    return this.webhook!=null?this.webhook.build():null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion buildWebhook() {
    return this.webhook!=null?this.webhook.build():null;
  }
  public A withWebhook(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion webhook) {
    _visitables.get("webhook").remove(this.webhook);
    if (webhook!=null){ this.webhook= new io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionBuilder(webhook); _visitables.get("webhook").add(this.webhook);} return (A) this;
  }
  public java.lang.Boolean hasWebhook() {
    return this.webhook != null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> withNewWebhook() {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluentImpl.WebhookNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> withNewWebhookLike(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion item) {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluentImpl.WebhookNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> editWebhook() {
    return withNewWebhookLike(getWebhook());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> editOrNewWebhook() {
    return withNewWebhookLike(getWebhook() != null ? getWebhook(): new io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> editOrNewWebhookLike(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion item) {
    return withNewWebhookLike(getWebhook() != null ? getWebhook(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CustomResourceConversionFluentImpl that = (CustomResourceConversionFluentImpl) o;
    if (strategy != null ? !strategy.equals(that.strategy) :that.strategy != null) return false;
    if (webhook != null ? !webhook.equals(that.webhook) :that.webhook != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(strategy,  webhook,  super.hashCode());
  }
  public class WebhookNestedImpl<N> extends io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<N>> implements io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    WebhookNestedImpl(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion item) {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionBuilder(this, item);
    }
    WebhookNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionBuilder(this);
    }
    io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionBuilder builder;
    public N and() {
      return (N) CustomResourceConversionFluentImpl.this.withWebhook(builder.build());
    }
    public N endWebhook() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-apiextensions-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceConversionFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class CustomResourceConversionFluentImpl<A extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent<A>{
  public CustomResourceConversionFluentImpl() {
  }
  public CustomResourceConversionFluentImpl(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversion instance) {
    this.withStrategy(instance.getStrategy()); 
    this.withWebhook(instance.getWebhook()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String strategy;
  private io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionBuilder webhook;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getStrategy() {
    return this.strategy;
  }
  public A withStrategy(java.lang.String strategy) {
    this.strategy=strategy; return (A) this;
  }
  public java.lang.Boolean hasStrategy() {
    return this.strategy != null;
  }
  
  /**
   * Method is deprecated. use withStrategy instead.
   */
  @java.lang.Deprecated
  public A withNewStrategy(java.lang.String arg0) {
    return (A)withStrategy(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildWebhook instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion getWebhook() {
    return this.webhook!=null?this.webhook.build():null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion buildWebhook() {
    return this.webhook!=null?this.webhook.build():null;
  }
  public A withWebhook(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion webhook) {
    _visitables.get("webhook").remove(this.webhook);
    if (webhook!=null){ this.webhook= new io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionBuilder(webhook); _visitables.get("webhook").add(this.webhook);} return (A) this;
  }
  public java.lang.Boolean hasWebhook() {
    return this.webhook != null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> withNewWebhook() {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluentImpl.WebhookNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> withNewWebhookLike(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion item) {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluentImpl.WebhookNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> editWebhook() {
    return withNewWebhookLike(getWebhook());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> editOrNewWebhook() {
    return withNewWebhookLike(getWebhook() != null ? getWebhook(): new io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> editOrNewWebhookLike(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion item) {
    return withNewWebhookLike(getWebhook() != null ? getWebhook(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CustomResourceConversionFluentImpl that = (CustomResourceConversionFluentImpl) o;
    if (strategy != null ? !strategy.equals(that.strategy) :that.strategy != null) return false;
    if (webhook != null ? !webhook.equals(that.webhook) :that.webhook != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(strategy,  webhook,  additionalProperties,  super.hashCode());
  }
  public class WebhookNestedImpl<N> extends io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<N>> implements io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    WebhookNestedImpl(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion item) {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionBuilder(this, item);
    }
    WebhookNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionBuilder(this);
    }
    io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionBuilder builder;
    public N and() {
      return (N) CustomResourceConversionFluentImpl.this.withWebhook(builder.build());
    }
    public N endWebhook() {
      return and();
    }
    
  }
  
}
